Index: trunk/MagicSoft/Mars/manalysis/MSourcePosfromStarPos.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MSourcePosfromStarPos.h	(revision 3831)
+++ trunk/MagicSoft/Mars/manalysis/MSourcePosfromStarPos.h	(revision 3847)
@@ -29,5 +29,5 @@
 class TList;
 class MRawRunHeader;
-class MMcEvt;
+class MPointingPos;
 class MGeomCam;
 class MSrcPosCam;
@@ -40,5 +40,5 @@
     const MRawRunHeader *fRun;      //!
     const MGeomCam      *fGeomCam;  //! Camera Geometry used to calculate Hillas
-    MMcEvt              *fMcEvt;    //!
+    MPointingPos        *fPointPos;       //!
     MSrcPosCam          *fSrcPos;         //!
     MObservatory        *fObservatory;    //!

Index: trunk/MagicSoft/Mars/manalysis/MSourcePosfromStarPos.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MSourcePosfromStarPos.cc	(revision 3831)
+++ trunk/MagicSoft/Mars/manalysis/MSourcePosfromStarPos.cc	(revision 3847)
@@ -1,2 +1,3 @@
+
 /* ======================================================================== *\
 !
@@ -54,5 +55,5 @@
 #include "MGeomCam.h"
 #include "MSrcPosCam.h"
-#include "MMcEvt.hxx"
+#include "MPointingPos.h"
 
 #include "MLog.h"
@@ -246,8 +247,9 @@
 
 
-   fMcEvt = (MMcEvt*)pList->FindCreateObj("MMcEvt");
-   if (!fMcEvt)
+
+   fPointPos = (MPointingPos*)pList->FindCreateObj("MPointingPos");
+   if (!fPointPos)
    {
-       *fLog << err << "MSourcePosfromStarPos::PreProcess; MMcEvt not found... aborting." << endl;
+       *fLog << err << "MSourcePosfromStarPos::PreProcess; MPointingPos not found... aborting." << endl;
        return kFALSE;
    }
@@ -502,5 +504,5 @@
     {
       //-----------------------------------------
       // put the zenith angle into MMcEvt
 
       Double_t thetarad = fThetaTel[i];
@@ -516,7 +518,6 @@
         fPhiradold = phirad;
 
-      fMcEvt->SetTelescopeTheta(thetarad);
-      fMcEvt->SetTelescopePhi(phirad);
-      fMcEvt->SetReadyToSave();
+      fPointPos->SetLocalPosition(thetarad*kRad2Deg, phirad*kRad2Deg);
+      fPointPos->SetReadyToSave();
 
       *fLog << all << "theta, phi = " << thetarad*kRad2Deg << ",  "
@@ -588,9 +589,8 @@
 
     Double_t thetarad = fThetaradold;
-    fMcEvt->SetTelescopeTheta(thetarad);
-
     Double_t phirad = fPhiradold;
-    fMcEvt->SetTelescopePhi(phirad);
-    fMcEvt->SetReadyToSave();
+    fPointPos->SetLocalPosition(thetarad*kRad2Deg, phirad*kRad2Deg);
+    fPointPos->SetReadyToSave();
+
 
     *fLog << warn << "MSourcePosfromStarPos::ReInit;  no information on theta, phi and source position for run number = "
@@ -502,5 +504,5 @@
     {
       //-----------------------------------------
-      // put the zenith angle into MMcEvt
+      // put the zenith angle into MPointingPos
 
       Double_t thetarad = fThetaTel[i];